@@ -2,14 +2,13 @@ package Parallel::Tiny;
 use strict;
 use warnings;
 use POSIX qw(WNOHANG);
-use Log::Log4perl qw(:easy);
 
 use constant DEFAULT_ERROR_TIMEOUT => 10;
 use constant DEFAULT_WORKERS       => 1;
 use constant DEFAULT_REAP_TIMEOUT  => .1;
 use constant DEFAULT_WORKER_TOTAL  => 1;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 =head1 NAME
 
@@ -55,9 +54,6 @@ takes arguments as a hash or hashref with the following arguments:
             waitpid() to reap children
             (default .1)
 
-  kill_all - When the parent gets TERM, kill all child processes immediately.
-            (default 0)
-
 You can for instance, say that you want to run 100 proccesses,
 but only 4 at a time like this:
 
@@ -79,13 +75,12 @@ sub new {
     # check arguments
     my $handler = $args->{handler};
     die 'no handler provided' unless $handler;
-    die 'handler does not implement a run() function'     unless $handler->can('run');
+    die 'handler does not implement a run() function' unless $handler->can('run');
 
     # set some defaults
     $args->{workers}      ||= DEFAULT_WORKERS;
     $args->{reap_timeout} ||= DEFAULT_REAP_TIMEOUT;
     $args->{worker_total} ||= DEFAULT_WORKER_TOTAL;
-    $args->{kill_all}     ||= 0;
 
     # special configuration
     undef $args->{worker_total} if $args->{worker_total} eq 'infinite';
@@ -94,10 +89,9 @@ sub new {
             _continue     => 1,
             _handler      => $handler,
             _jobs         => {},
-            _workers     => $args->{workers},
+            _workers      => $args->{workers},
             _reap_timeout => $args->{reap_timeout},
-            _worker_total   => $args->{worker_total},
-            _kill_all     => $args->{kill_all},
+            _worker_total => $args->{worker_total},
     }, $class);
 }
 
@@ -110,13 +104,7 @@ Start spooling jobs according to the configuration.
 sub run {
     my $self = shift;
 
-    # setup signal handlers
-    $SIG{TERM} = sub {
-        if ($self->{_kill_all}) {
-            kill 9, keys(@{ $self->{_jobs} });
-        }
-        $self->{_continue} = 0;
-    };
+    local $SIG{TERM} = sub { $self->{_continue} = 0 };
 
     # setup the fork manager
     my $handler = $self->{_handler};
@@ -131,11 +119,8 @@ sub run {
         }
 
         # child work
-        $SIG{CHLD} = 'DEFAULT';
-        eval { $handler->run() };
-        if ($@) {
-            exit 1;
-        }
+        $0 = $0 . ' - worker';
+        $handler->run();
 
         # child cleanup
         exit 0;
@@ -157,11 +142,11 @@ sub waitqueue {
     my $self = shift;
 
     # check for any stopping conditions
-    return 0 unless $self->{_continue};
     return 0 if defined $self->{_worker_total} and $self->{_worker_total} <= 0;
 
     # wait to reap at least one child
     while (keys(%{ $self->{_jobs} }) >= $self->{_workers}) {
+        return 0 unless $self->{_continue};
         $self->_reapchildren();
         sleep $self->{_reap_timeout};
     }
